changeset 328:a7c1dbcf5e00

Added a seek method stub.
author Ryan C. Gordon <icculus@icculus.org>
date Mon, 20 May 2002 06:55:23 +0000
parents aa7f6a110971
children 41c650d468c3
files decoders/quicktime.c
diffstat 1 files changed, 16 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/decoders/quicktime.c	Mon May 20 06:46:43 2002 +0000
+++ b/decoders/quicktime.c	Mon May 20 06:55:23 2002 +0000
@@ -73,6 +73,7 @@
 static void QT_close(Sound_Sample *sample);
 static Uint32 QT_read(Sound_Sample *sample);
 static int QT_rewind(Sound_Sample *sample);
+static int QT_seek(Sound_Sample *sample, Uint32 ms);
 
 #define QT_MAX_INPUT_BUFFER (32*1024) /* Maximum size of internal buffer (internal->buffer_size) */
 
@@ -86,12 +87,13 @@
       "http://www.icculus.org/SDL_sound/"
     },
     
-    QT_init,       /*   init() method */
-    QT_quit,       /*   quit() method */
-    QT_open,       /*   open() method */
-    QT_close,      /*   close() method */
-    QT_read,       /*   read() method */
-    QT_rewind      /*   rewind() method */
+    QT_init,       /* init() method   */
+    QT_quit,       /* quit() method   */
+    QT_open,       /* open() method   */
+    QT_close,      /* close() method  */
+    QT_read,       /* read() method   */
+    QT_rewind,     /* rewind() method */
+    QT_seek        /* seek() method   */
   };
 
 typedef struct {
@@ -577,6 +579,14 @@
     
 } /* QT_rewind */
 
+
+static int QT_seek(Sound_Sample *sample, Uint32 ms)
+{
+    /* !!! FIXME: Implement this! */
+    return(0);
+} /* QT_seek */
+
+
 #endif /* SOUND_SUPPORTS_QUICKTIME */
 
 /* end of quicktime.c ... */